BufferTextureCopyLocation

Struct BufferTextureCopyLocation 

pub struct BufferTextureCopyLocation<'frame> {
    pub buffer: Buffer<'frame>,
    pub layout: TexelCopyBufferLayout,
}
One logical buffer and texel layout used by a buffer-texture copy operation.

Fields

buffer: Buffer<'frame>

Logical source or destination buffer.

layout: TexelCopyBufferLayout

Texel-copy layout within the buffer.

Implementations

Source

impl<'frame> BufferTextureCopyLocation<'frame>

pub const fn new(buffer: Buffer<'frame>, layout: TexelCopyBufferLayout) -> Self

Creates a logical buffer copy location with an explicit texel layout.