pub struct TextureViewDesc {
pub label: String,
pub format: Option<TextureFormat>,
pub dimension: Option<TextureViewDimension>,
pub aspect: TextureAspect,
pub base_mip_level: u32,
pub mip_level_count: Option<u32>,
pub base_array_layer: u32,
pub array_layer_count: Option<u32>,
}Expand description
Descriptor for a logical texture view.
Optional counts extend from their base through the remaining texture subresources. Optional format and dimension use wgpu-compatible defaults.
Fields
label: StringDiagnostic view label.
format: Option<TextureFormat>View format, or the underlying texture format when omitted.
dimension: Option<TextureViewDimension>View dimension, or the dimension inferred from the texture when omitted.
aspect: TextureAspectSelected texture aspect.
base_mip_level: u32First selected mip level.
mip_level_count: Option<u32>Selected mip count, or all remaining mips.
base_array_layer: u32First selected array layer.
array_layer_count: Option<u32>Selected array-layer count, or all remaining layers.