pub struct BufferTextureCopyLocation<'frame> {
pub buffer: Buffer<'frame>,
pub layout: TexelCopyBufferLayout,
}Expand description
One logical buffer and texel layout used by a buffer-texture copy operation.
Fields
buffer: Buffer<'frame>Logical source or destination buffer.
layout: TexelCopyBufferLayoutTexel-copy layout within the buffer.
Implementations
Sourceimpl<'frame> BufferTextureCopyLocation<'frame>
impl<'frame> BufferTextureCopyLocation<'frame>
Sourcepub const fn new(buffer: Buffer<'frame>, layout: TexelCopyBufferLayout) -> Self
pub const fn new(buffer: Buffer<'frame>, layout: TexelCopyBufferLayout) -> Self
Creates a logical buffer copy location with an explicit texel layout.